# TrustZone code generator

Trustzone module code generator for the Authentic Execution framework

## Installation

```bash
# from the root of this repository
pip install .
```

## Run

```bash
#TODO
```

## General rules

TODO